@@ -1,17 +1,18 @@
 context("get_elev_raster")
+library(sp)
+library(elevatr)
 data("pt_df")
 data("sp_big")
 data("lake")
-library(sp)
-ll_prj <- "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs +towgs84=0,0,0"
-aea_prj <- "+proj=aea +lat_1=20 +lat_2=60 +lat_0=40 +lon_0=-96 +x_0=0 +y_0=0 +datum=NAD83 +units=m +no_defs +ellps=GRS80 +towgs84=0,0,0"
 
-sp_sm <- SpatialPoints(coordinates(pt_df),CRS(ll_prj))
+ll_prj  <- "+proj=longlat +datum=WGS84 +no_defs"
+aea_prj <- "+proj=aea +lat_0=40 +lon_0=-96 +lat_1=20 +lat_2=60 +x_0=0 +y_0=0 +ellps=GRS80 +units=m +no_defs"
+
+sp_sm     <- SpatialPoints(coordinates(pt_df),CRS(ll_prj))
 sp_sm_prj <- spTransform(sp_sm,CRS(aea_prj))
 
 test_that("get_elev_raster returns correctly", {
   skip_on_cran()
-  skip_on_appveyor()
   
   aws <- get_elev_raster(locations = sp_sm, z = 6, src = "aws")
   aws_prj <- get_elev_raster(locations = sp_sm_prj, z = 6, src = "aws")
@@ -28,7 +29,6 @@ test_that("get_elev_raster returns correctly", {
 
 test_that("get_elev_raster clip argument works", {
   skip_on_cran()
-  skip_on_appveyor()
   
   default_clip <- get_elev_raster(lake, z = 5, clip = "tile")
   bbox_clip <- get_elev_raster(lake, z = 5, clip = "bbox")
@@ -45,3 +45,27 @@ test_that("get_elev_raster clip argument works", {
   expect_true(num_cell_bbox > num_cell_locations)
 })
 
+test_that("get_elev_raster returns correctly from opentopo", {
+  skip_on_cran()
+  
+  gl1 <- get_elev_raster(locations = sp_sm[3:4,], src = "gl1", neg_to_na = TRUE)
+  gl1_prj <- get_elev_raster(locations = sp_sm_prj[3:4,], src = "gl1", 
+                             clip = "bbox")
+  
+  #class
+  expect_is(gl1,"RasterLayer")
+  expect_is(gl1_prj,"RasterLayer")
+  
+  #project
+  expect_equal(proj4string(gl1),ll_prj)
+  expect_equal(proj4string(gl1_prj),aea_prj)
+  
+})
+
+test_that("A resp that isn't a tiff or octet-stream works",{
+  bad_sp <- SpatialPoints(coordinates(data.frame(x = 1000, y = 1000)),
+                             CRS(ll_prj))
+  
+  expect_error(get_elev_raster(bad_sp, z = 6))
+  expect_error(get_elev_raster(bad_sp, src = "gl3"))
+})
